agentle.mcp.sampling.model\_preferences
=======================================

.. automodule:: agentle.mcp.sampling.model_preferences

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      Hint
      ModelPreference
   